Module: Flowckerc

Defined in:
lib/flowckerc/tokens.rb,
lib/flowckerc.rb,
lib/flowckerc/formula.rb,
lib/flowckerc/version.rb

Overview

Copyright © 2015 Leopoldo Lara Vazquez.

This program is free software: you can redistribute it and/or  modify
it under the terms of the GNU Affero General Public License, version 3,
as published by the Free Software Foundation.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU Affero General Public License for more details.

You should have received a copy of the GNU Affero General Public License
along with this program.  If not, see <http://www.gnu.org/licenses/>.

Defined Under Namespace

Modules: UniqueID Classes: Atom, Formula, FormulaSolution, Link, Molecule, MoleculePorts, SolverClass, SymTable

Constant Summary collapse

Solver =
SolverClass.new
VERSION =
"0.0.0"